@@ -7,6 +7,8 @@
 #include <libfilezilla/socket.hpp>
 
 #include "oplock_manager.h"
+#include "server.h"
+#include "serverpath.h"
 
 class COpData
 {
@@ -43,7 +45,7 @@ public:
 
 	wchar_t const* const name_;
 
-	MessageType sendLogLevel_{MessageType::Debug_Verbose};
+	logmsg::type sendLogLevel_{logmsg::debug_verbose};
 };
 
 template<typename T>
@@ -61,8 +63,8 @@ public:
 	virtual ~CProtocolOpData() = default;
 
 	template<typename...Args>
-	void LogMessage(Args&& ...args) const {
-		controlSocket_.LogMessage(std::forward<Args>(args)...);
+	void log(Args&& ...args) const {
+		controlSocket_.log(std::forward<Args>(args)...);
 	}
 
 	T & controlSocket_;
@@ -150,9 +152,12 @@ enum class TransferEndReason
 	failed_resumetest
 };
 
-class SocketLayer;
+namespace fz {
+class socket_layer;
+}
+class CFileExistsNotification;
 class CTransferStatus;
-class CControlSocket: public CLogging, public fz::event_handler
+class CControlSocket : public fz::event_handler
 {
 public:
 	CControlSocket(CFileZillaEnginePrivate & engine);
@@ -186,7 +191,7 @@ public:
 	Command GetCurrentCommandId() const;
 
 	void SendAsyncRequest(CAsyncRequestNotification* pNotification);
-	virtual bool SetAsyncRequestReply(CAsyncRequestNotification *pNotification) = 0;
+	void CallSetAsyncRequestReply(CAsyncRequestNotification *pNotification);
 	bool SetFileExistsAction(CFileExistsNotification *pFileExistsNotification);
 
 	CServer const& GetCurrentServer() const;
@@ -215,10 +220,19 @@ public:
 	// Only called from the engine, see there for description
 	void InvalidateCurrentWorkingDir(const CServerPath& path);
 
-	virtual bool CanSendNextCommand() const { return true; }
+	virtual bool CanSendNextCommand() { return true; }
 	int SendNextCommand();
 
+	template<typename ...Args>
+	void log(Args&& ... args) {
+		logger_.log(std::forward<Args>(args)...);
+	}
+	template<typename ...Args>
+	void log_raw(Args&& ... args) {
+		logger_.log_raw(std::forward<Args>(args)...);
+	}
 protected:
+	virtual bool SetAsyncRequestReply(CAsyncRequestNotification *pNotification) = 0;
 	void SendDirectoryListingNotification(CServerPath const& path, bool failed);
 
 	fz::duration GetTimezoneOffset() const;
@@ -263,6 +277,8 @@ protected:
 	bool m_invalidateCurrentPath{};
 	ServerHandle handle_;
 
+	fz::logger_interface& logger_;
+
 	virtual void operator()(fz::event_base const& ev);
 
 	void OnTimer(fz::timer_id id);
@@ -270,7 +286,7 @@ protected:
 };
 
 class CProxySocket;
-class CSocketBackend;
+class CRatelimitLayer;
 
 class CRealControlSocket : public CControlSocket
 {
@@ -301,11 +317,11 @@ protected:
 	}
 
 	std::unique_ptr<fz::socket> socket_;
-	std::unique_ptr<CSocketBackend> ratelimit_layer_;
+	std::unique_ptr<CRatelimitLayer> ratelimit_layer_;
 	std::unique_ptr<CProxySocket> proxy_layer_;
-	SocketLayer* active_layer_{};
+	fz::socket_layer* active_layer_{};
 
-	fz::buffer sendBuffer_;
+	fz::buffer send_buffer_;
 };
 
 #endif
