@@ -1,7 +1,8 @@
 #include <filezilla.h>
 
-CConnectCommand::CConnectCommand(CServer const& server, Credentials const& credentials, bool retry_connecting)
+CConnectCommand::CConnectCommand(CServer const& server, ServerHandle const& handle, Credentials const& credentials, bool retry_connecting)
 	: server_(server)
+	, handle_(handle)
 	, credentials_(credentials)
 	, retry_connecting_(retry_connecting)
 {
@@ -37,16 +38,19 @@ std::wstring CListCommand::GetSubDir() const
 
 bool CListCommand::valid() const
 {
-	if (GetPath().empty() && !GetSubDir().empty())
+	if (GetPath().empty() && !GetSubDir().empty()) {
 		return false;
+	}
 
-	if (GetFlags() & LIST_FLAG_LINK && GetSubDir().empty())
+	if (GetFlags() & LIST_FLAG_LINK && GetSubDir().empty()) {
 		return false;
+	}
 
 	bool const refresh = (m_flags & LIST_FLAG_REFRESH) != 0;
 	bool const avoid = (m_flags & LIST_FLAG_AVOID) != 0;
-	if (refresh && avoid)
+	if (refresh && avoid) {
 		return false;
+	}
 
 	return true;
 }
