@@ -15,6 +15,7 @@
 class CControlSocket;
 class CLogging;
 class CRateLimiter;
+class OpLockManager;
 
 enum EngineNotificationType
 {
@@ -90,6 +91,7 @@ public:
 	CDirectoryCache& GetDirectoryCache() { return directory_cache_; }
 	CPathCache& GetPathCache() { return path_cache_; }
 	fz::thread_pool& GetThreadPool() { return thread_pool_; }
+	CFileZillaEngineContext& GetContext() { return context_; }
 
 	// If deleting or renaming a directory, it could be possible that another
 	// engine's CControlSocket instance still has that directory as
@@ -100,11 +102,16 @@ public:
 	// directory.
 	void InvalidateCurrentWorkingDirs(const CServerPath& path);
 
-	unsigned int GetEngineId() const {return m_engine_id; }
+	unsigned int GetEngineId() const { return m_engine_id; }
 
 	CTransferStatusManager transfer_status_;
 
 	CustomEncodingConverterBase const& GetEncodingConverter() const { return encoding_converter_; }
+
+	OpLockManager & opLockManager_;
+
+	fz::logger_interface& GetLogger();
+
 protected:
 	virtual void OnOptionsChanged(changed_options_t const& options);
 
@@ -173,7 +180,7 @@ protected:
 
 	COptionsBase& m_options;
 
-	CLogging* m_pLogging;
+	std::unique_ptr<CLogging> logger_;
 
 	// Everything related to the retry code
 	// ------------------------------------
@@ -200,11 +207,14 @@ protected:
 	CFileZillaEngine& parent_;
 
 	bool queue_logs_{true};
+
 	std::vector<CLogmsgNotification*> queued_logs_;
 
 	fz::thread_pool & thread_pool_;
 
 	CustomEncodingConverterBase const& encoding_converter_;
+
+	CFileZillaEngineContext& context_;
 };
 
 struct command_event_type{};
