@@ -14,10 +14,11 @@ enum mkdStates
 
 int CFtpMkdirOpData::Send()
 {
-	if (!holdsLock_) {
-		if (!controlSocket_.TryLock(locking_reason::mkdir, path_)) {
-			return FZ_REPLY_WOULDBLOCK;
-		}
+	if (!opLock_) {
+		opLock_ = controlSocket_.Lock(locking_reason::mkdir, path_);
+	}
+	if (opLock_.waiting()) {
+		return FZ_REPLY_WOULDBLOCK;
 	}
 
 	switch (opState)
@@ -61,7 +62,7 @@ int CFtpMkdirOpData::Send()
 	case mkd_tryfull:
 		return controlSocket_.SendCommand(L"MKD " + path_.GetPath());
 	default:
-		LogMessage(MessageType::Debug_Warning, L"unknown op state: %d", opState);
+		log(logmsg::debug_warning, L"unknown op state: %d", opState);
 		break;
 	}
 
@@ -94,9 +95,9 @@ int CFtpMkdirOpData::ParseResponse()
 			// Don't fall back to using the full path if the error message
 			// is "already exists".
 			// Case 1: Full response a known "already exists" message.
-			// Case 2: Substrng of response contains "already exists". path may not
+			// Case 2: Substring of response contains "already exists". path may not
 			//         contain this substring as the path might be returned in the reply.
-			// Case 3: Substrng of response contains "file exists". path may not
+			// Case 3: Substring of response contains "file exists". path may not
 			//         contain this substring as the path might be returned in the reply.
 			std::wstring const response = fz::str_tolower_ascii(controlSocket_.m_Response.substr(4));
 			std::wstring const p = fz::str_tolower_ascii(path_.GetPath());
@@ -114,7 +115,7 @@ int CFtpMkdirOpData::ParseResponse()
 
 		{
 			if (segments_.empty()) {
-				LogMessage(MessageType::Debug_Warning, L"  segments is empty");
+				log(logmsg::debug_warning, L"  segments is empty");
 				return FZ_REPLY_INTERNALERROR;
 			}
 
@@ -129,7 +130,7 @@ int CFtpMkdirOpData::ParseResponse()
 			}
 
 			engine_.GetDirectoryCache().UpdateFile(currentServer_, currentMkdPath_, segments_.back(), true, CDirectoryCache::dir);
-			controlSocket_.SendDirectoryListingNotification(currentMkdPath_, false, false);
+			controlSocket_.SendDirectoryListingNotification(currentMkdPath_, false);
 
 			currentMkdPath_.AddSegment(segments_.back());
 			segments_.pop_back();
@@ -160,7 +161,7 @@ int CFtpMkdirOpData::ParseResponse()
 		}
 		break;
 	default:
-		LogMessage(MessageType::Debug_Warning, L"unknown op state: %d", opState);
+		log(logmsg::debug_warning, L"unknown op state: %d", opState);
 	}
 
 	return FZ_REPLY_INTERNALERROR;
