@@ -7,13 +7,13 @@ int CSftpDeleteOpData::Send()
 {
 	std::wstring const& file = files_.front();
 	if (file.empty()) {
-		LogMessage(MessageType::Debug_Info, L"Empty filename");
+		log(logmsg::debug_info, L"Empty filename");
 		return FZ_REPLY_INTERNALERROR;
 	}
 
 	std::wstring filename = path_.FormatFilename(file);
 	if (filename.empty()) {
-		LogMessage(MessageType::Error, _("Filename cannot be constructed for directory %s and filename %s"), path_.GetPath(), file);
+		log(logmsg::error, _("Filename cannot be constructed for directory %s and filename %s"), path_.GetPath(), file);
 		return FZ_REPLY_ERROR;
 	}
 
@@ -38,7 +38,7 @@ int CSftpDeleteOpData::ParseResponse()
 
 		auto const now = fz::datetime::now();
 		if (!time_.empty() && (now - time_).get_seconds() >= 1) {
-			controlSocket_.SendDirectoryListingNotification(path_, false, false);
+			controlSocket_.SendDirectoryListingNotification(path_, false);
 			time_ = now;
 			needSendListing_ = false;
 		}
@@ -64,7 +64,7 @@ int CSftpDeleteOpData::SubcommandResult(int, COpData const&)
 int CSftpDeleteOpData::Reset(int result)
 {
 	if (needSendListing_ && !(result & FZ_REPLY_DISCONNECTED)) {
-		controlSocket_.SendDirectoryListingNotification(path_, false, false);
+		controlSocket_.SendDirectoryListingNotification(path_, false);
 	}
 	return result;
 }
