@@ -15,7 +15,7 @@ int CSftpListOpData::Send()
 {
 	if (opState == list_init) {
 		if (!currentServer_) {
-			LogMessage(MessageType::Debug_Warning, L"currenServer_ is empty");
+			log(logmsg::debug_warning, L"currenServer_ is empty");
 			return FZ_REPLY_INTERNALERROR;
 		}
 
@@ -37,17 +37,18 @@ int CSftpListOpData::Send()
 		bool is_outdated = false;
 		bool found = engine_.GetDirectoryCache().Lookup(listing, currentServer_, path_, false, is_outdated);
 		if (found && !is_outdated &&
-			(!refresh_ || (holdsLock_ && listing.m_firstListTime >= time_before_locking_)))
+			(!refresh_ || (opLock_ && listing.m_firstListTime >= time_before_locking_)))
 		{
-			controlSocket_.SendDirectoryListingNotification(listing.path, topLevel_, false);
+			controlSocket_.SendDirectoryListingNotification(listing.path, false);
 			return FZ_REPLY_OK;
 		}
 
-		if (!holdsLock_) {
-			if (!controlSocket_.TryLock(locking_reason::list, currentPath_)) {
-				time_before_locking_ = fz::monotonic_clock::now();
-				return FZ_REPLY_WOULDBLOCK;
-			}
+		if (!opLock_) {
+			opLock_ = controlSocket_.Lock(locking_reason::list, currentPath_);
+			time_before_locking_ = fz::monotonic_clock::now();
+		}
+		if (opLock_.waiting()) {
+			return FZ_REPLY_WOULDBLOCK;
 		}
 
 		opState = list_list;
@@ -58,7 +59,7 @@ int CSftpListOpData::Send()
 		return controlSocket_.SendCommand(L"ls");
 	}
 
-	LogMessage(MessageType::Debug_Warning, L"Unknown opState in CSftpControlSocket::ListSend()");
+	log(logmsg::debug_warning, L"Unknown opState in CSftpControlSocket::ListSend()");
 	return FZ_REPLY_INTERNALERROR;
 }
 
@@ -70,18 +71,18 @@ int CSftpListOpData::ParseResponse()
 		}
 
 		if (!listing_parser_) {
-			LogMessage(MessageType::Debug_Warning, L"listing_parser_ is empty");
+			log(logmsg::debug_warning, L"listing_parser_ is empty");
 			return FZ_REPLY_INTERNALERROR;
 		}
 
 		directoryListing_ = listing_parser_->Parse(currentPath_);
 		engine_.GetDirectoryCache().Store(directoryListing_, currentServer_);
-		controlSocket_.SendDirectoryListingNotification(currentPath_, topLevel_, false);
+		controlSocket_.SendDirectoryListingNotification(currentPath_, false);
 
 		return FZ_REPLY_OK;
 	}
 
-	LogMessage(MessageType::Debug_Warning, L"ListParseResponse called at improper time: %d", opState);
+	log(logmsg::debug_warning, L"ListParseResponse called at improper time: %d", opState);
 	return FZ_REPLY_INTERNALERROR;
 }
 
@@ -114,14 +115,14 @@ int CSftpListOpData::SubcommandResult(int prevResult, COpData const&)
 int CSftpListOpData::ParseEntry(std::wstring && entry, uint64_t mtime, std::wstring && name)
 {
 	if (opState != list_list) {
-		controlSocket_.LogMessageRaw(MessageType::RawList, entry);
-		LogMessage(MessageType::Debug_Warning, L"CSftpListOpData::ParseEntry called at improper time: %d", opState);
+		controlSocket_.log_raw(logmsg::listing, entry);
+		log(logmsg::debug_warning, L"CSftpListOpData::ParseEntry called at improper time: %d", opState);
 		return FZ_REPLY_INTERNALERROR;
 	}
 
 	if (!listing_parser_) {
-		controlSocket_.LogMessageRaw(MessageType::RawList, entry);
-		LogMessage(MessageType::Debug_Warning, L"listing_parser_ is null");
+		controlSocket_.log_raw(logmsg::listing, entry);
+		log(logmsg::debug_warning, L"listing_parser_ is null");
 		return FZ_REPLY_INTERNALERROR;
 	}
 
