@@ -16,7 +16,7 @@ int CStorjListOpData::Send()
 	switch (opState) {
 	case list_init:
 		if (!subDir_.empty()) {
-			LogMessage(MessageType::Error, _("Invalid path"));
+			log(logmsg::error, _("Invalid path"));
 			return FZ_REPLY_ERROR;
 		}
 
@@ -27,12 +27,12 @@ int CStorjListOpData::Send()
 		currentPath_ = path_;
 
 		if (!currentServer_) {
-			LogMessage(MessageType::Debug_Warning, L"CStorjControlSocket::List called with m_pCurrenServer == 0");
+			log(logmsg::debug_warning, L"CStorjControlSocket::List called with m_pCurrenServer == 0");
 			return FZ_REPLY_INTERNALERROR;
 		}
 
 		if (currentPath_.GetType() != ServerType::UNIX) {
-			LogMessage(MessageType::Debug_Warning, L"CStorControlSocket::List called with incompatible server type %d in path", currentPath_.GetType());
+			log(logmsg::debug_warning, L"CStorControlSocket::List called with incompatible server type %d in path", currentPath_.GetType());
 			return FZ_REPLY_INTERNALERROR;
 		}
 
@@ -40,8 +40,8 @@ int CStorjListOpData::Send()
 		controlSocket_.Resolve(path_, std::wstring(), bucket_);
 		return FZ_REPLY_CONTINUE;
 	case list_waitlock:
-		if (!holdsLock_) {
-			LogMessage(MessageType::Debug_Warning, L"Not holding the lock as expected");
+		if (!opLock_) {
+			log(logmsg::debug_warning, L"Not holding the lock as expected");
 			return FZ_REPLY_INTERNALERROR;
 		}
 
@@ -53,7 +53,7 @@ int CStorjListOpData::Send()
 			if (found && !is_outdated &&
 				listing.m_firstListTime >= time_before_locking_)
 			{
-				controlSocket_.SendDirectoryListingNotification(listing.path, topLevel_, false);
+				controlSocket_.SendDirectoryListingNotification(listing.path, false);
 				return FZ_REPLY_OK;
 			}
 		}
@@ -77,7 +77,7 @@ int CStorjListOpData::Send()
 		}
 	}
 
-	LogMessage(MessageType::Debug_Warning, L"Unknown opState in CStorjListOpData::ListSend()");
+	log(logmsg::debug_warning, L"Unknown opState in CStorjListOpData::ListSend()");
 	return FZ_REPLY_INTERNALERROR;
 }
 
@@ -93,13 +93,13 @@ int CStorjListOpData::ParseResponse()
 		listing.Assign(std::move(entries_));
 
 		engine_.GetDirectoryCache().Store(listing, currentServer_);
-		controlSocket_.SendDirectoryListingNotification(listing.path, topLevel_, false);
+		controlSocket_.SendDirectoryListingNotification(listing.path, false);
 
 		currentPath_ = path_;
 		return FZ_REPLY_OK;
 	}
 
-	LogMessage(MessageType::Debug_Warning, L"CStorjListOpData::ParseResponse called at improper time: %d", opState);
+	log(logmsg::debug_warning, L"CStorjListOpData::ParseResponse called at improper time: %d", opState);
 	return FZ_REPLY_INTERNALERROR;
 }
 
@@ -112,8 +112,11 @@ int CStorjListOpData::SubcommandResult(int prevResult, COpData const&)
 	switch (opState) {
 	case list_waitresolve:
 		opState = list_waitlock;
-		if (!controlSocket_.TryLock(locking_reason::list, path_)) {
+		if (!opLock_) {
+			opLock_ = controlSocket_.Lock(locking_reason::list, path_);
 			time_before_locking_ = fz::monotonic_clock::now();
+		}
+		if (opLock_.waiting()) {
 			return FZ_REPLY_WOULDBLOCK;
 		}
 
@@ -121,14 +124,14 @@ int CStorjListOpData::SubcommandResult(int prevResult, COpData const&)
 		return FZ_REPLY_CONTINUE;
 	}
 
-	LogMessage(MessageType::Debug_Warning, L"Unknown opState in CStorjListOpData::SubcommandResult()");
+	log(logmsg::debug_warning, L"Unknown opState in CStorjListOpData::SubcommandResult()");
 	return FZ_REPLY_INTERNALERROR;
 }
 
 int CStorjListOpData::ParseEntry(std::wstring && name, std::wstring const& size, std::wstring && id, std::wstring const& created)
 {
 	if (opState != list_list) {
-		LogMessage(MessageType::Debug_Warning, L"CStorjListOpData::ParseEntry called at improper time: %d", opState);
+		log(logmsg::debug_warning, L"CStorjListOpData::ParseEntry called at improper time: %d", opState);
 		return FZ_REPLY_INTERNALERROR;
 	}
 
