@@ -7,10 +7,12 @@ class CDirectoryCache;
 class COptionsBase;
 class CPathCache;
 class CRateLimiter;
+class OpLockManager;
 
 namespace fz {
 class event_loop;
 class thread_pool;
+class tls_system_trust_store;
 }
 
 
@@ -37,6 +39,8 @@ public:
 	CDirectoryCache& GetDirectoryCache();
 	CPathCache& GetPathCache();
 	CustomEncodingConverterBase const& GetCustomEncodingConverter() { return customEncodingConverter_; }
+	OpLockManager& GetOpLockManager();
+	fz::tls_system_trust_store& GetTlsSystemTrustStore();
 
 protected:
 	COptionsBase& options_;
