@@ -1,6 +1,7 @@
 #ifndef FILEZILLA_ENGINE_SERVER_HEADER
 #define FILEZILLA_ENGINE_SERVER_HEADER
 
+#include <map>
 #include <memory>
 
 enum ServerProtocol
@@ -38,7 +39,9 @@ enum ServerProtocol
 
 	BOX,
 
-	MAX_VALUE = BOX
+	INSECURE_WEBDAV,
+
+	MAX_VALUE = INSECURE_WEBDAV
 };
 
 enum ServerType
@@ -95,7 +98,8 @@ enum class ProtocolFeature
 	RecursiveDelete,
 	ServerAssignedHome,
 	TemporaryUrl,
-	S3Sse
+	S3Sse,
+	Security // Encryption, integrity protection and authentication
 };
 
 class Credentials;
