@@ -13,6 +13,7 @@
 #include "themeprovider.h"
 #include "wxfilesystem_blob_handler.h"
 #include <libfilezilla/local_filesys.hpp>
+#include <libfilezilla/translate.hpp>
 
 #include <wx/evtloop.h>
 
@@ -397,6 +398,8 @@ CLocalPath CFileZillaApp::GetDataDir(std::vector<std::wstring> const& fileToFind
 	};
 
 #ifdef __WXMAC__
+	(void)prefixSub;
+
 	if (searchSelfDir && testPath(wxStandardPaths::Get().GetDataDir().ToStdWstring())) {
 		return ret;
 	}
@@ -534,6 +537,7 @@ bool CFileZillaApp::SetLocale(int language)
 	if (!pLocale->AddCatalog(_T("filezilla")) && language != wxLANGUAGE_DEFAULT) {
 		return false;
 	}
+	pLocale->AddCatalog(_T("libfilezilla"));
 
 	if (m_pLocale) {
 		// Now unload old locale
@@ -550,6 +554,7 @@ bool CFileZillaApp::SetLocale(int language)
 		else if (!pLocale->AddCatalog(_T("filezilla")) && language != wxLANGUAGE_DEFAULT) {
 			return false;
 		}
+		pLocale->AddCatalog(_T("libfilezilla"));
 	}
 	m_pLocale = std::move(pLocale);
 
@@ -620,6 +625,8 @@ void CFileZillaApp::CheckExistsTool(std::wstring const& tool, std::wstring const
 
 	std::wstring program = tool;
 #ifdef __WXMAC__
+	(void)buildRelPath;
+
 	// On Mac we only look inside the bundle
 	std::wstring path = GetOwnExecutableDir();
 	if (!path.empty()) {
@@ -752,13 +759,30 @@ void CFileZillaApp::ShowStartupProfile()
 	if (m_profile_start && m_pCommandLine && m_pCommandLine->HasSwitch(CCommandLine::debug_startup)) {
 		AddStartupProfileRecord("CFileZillaApp::ShowStartupProfile");
 		wxString msg = _T("Profile:\n");
+
+		size_t const max_digits = fz::to_string((m_startupProfile.back().first - m_profile_start).get_milliseconds()).size();
+		
+		int64_t prev{};
 		for (auto const& p : m_startupProfile) {
 			auto const diff = p.first - m_profile_start;
+			auto absolute = std::to_wstring(diff.get_milliseconds());
+			if (absolute.size() < max_digits) {
+				msg.append(max_digits - absolute.size(), wchar_t(0x2007)); // FIGURE SPACE
+			}
+			msg += absolute;
+			msg += L" ";
+
+			auto relative = std::to_wstring(diff.get_milliseconds() - prev);
+			if (relative.size() < max_digits) {
+				msg.append(max_digits - relative.size(), wchar_t(0x2007)); // FIGURE SPACE
+			}
+			msg += relative;
+			msg += L" ";
 
-			msg += std::to_wstring(diff.get_milliseconds());
-			msg += _T(" ");
 			msg += fz::to_wstring(p.second);
-			msg += _T("\n");
+			msg += L"\n";
+
+			prev = diff.get_milliseconds();
 		}
 		wxMessageBoxEx(msg);
 	}
