@@ -115,7 +115,7 @@ static const t_Option options[OPTIONS_NUM] =
 	// Interface settings
 	{ "Number of Transfers", number, _T("2"), normal },
 	{ "Ascii Binary mode", number, _T("0"), normal },
-	{ "Auto Ascii files", string, _T("am|asp|bat|c|cfm|cgi|conf|cpp|css|dhtml|diz|h|hpp|htm|html|in|inc|java|js|jsp|lua|m4|mak|md5|nfo|nsi|pas|patch|php|phtml|pl|po|py|qmail|sh|sha1|sha256|sha512|shtml|sql|svg|tcl|tpl|txt|vbs|xhtml|xml|xrc"), normal },
+	{ "Auto Ascii files", string, _T("am|asp|bat|c|cfm|cgi|conf|cpp|css|dhtml|diz|h|hpp|htm|html|in|inc|java|js|jsp|lua|m4|mak|md5|nfo|nsi|pas|patch|pem|php|phtml|pl|po|py|qmail|sh|sha1|sha256|sha512|shtml|sql|svg|tcl|tpl|txt|vbs|xhtml|xml|xrc"), normal },
 	{ "Auto Ascii no extension", number, _T("1"), normal },
 	{ "Auto Ascii dotfiles", number, _T("1"), normal },
 	{ "Language Code", string, _T(""), normal },
@@ -305,7 +305,7 @@ std::unique_ptr<pugi::xml_document> COptions::GetOptionXml(unsigned int nID)
 	auto value = std::make_unique<pugi::xml_document>();
 	value->append_copy(m_optionsCache[nID].xmlValue->first_child());
 
-	return std::move(value);
+	return value;
 }
 
 bool COptions::SetOption(unsigned int nID, int value)
