@@ -691,11 +691,12 @@ struct sftp_request *fxp_close_send(struct fxp_handle *handle)
     return req;
 }
 
-void fxp_close_recv(struct sftp_packet *pktin, struct sftp_request *req)
+int fxp_close_recv(struct sftp_packet *pktin, struct sftp_request *req)
 {
     sfree(req);
     fxp_got_status(pktin);
     sftp_pkt_free(pktin);
+    return fxp_errtype == SSH_FX_OK;
 }
 
 struct sftp_request *fxp_mkdir_send(const char *path)
@@ -1262,6 +1263,7 @@ int xfer_download_gotpkt(struct fxp_xfer *xfer, struct sftp_packet *pktin)
 
     if ((rr->retlen < 0 && fxp_error_type()==SSH_FX_EOF) || rr->retlen == 0) {
 	xfer->eof = TRUE;
+        rr->retlen = 0;
 	rr->complete = -1;
 #ifdef DEBUG_DOWNLOAD
 	printf("setting eof\n");
